componenttools.sum_preprolated_duration_of_components
=====================================================

.. autofunction:: abjad.tools.componenttools.sum_preprolated_duration_of_components.sum_preprolated_duration_of_components
